Crate robuild

source ·

Macros

  • Call dis macro in your build recipe, and the program will rebuild itself, freeing you from the need to rebuilding your build recipe file
  • You can log things just like we do in Rob functions, pass the LogLevel enum variant and then format your output like you’r using the println! macro. For instance:
  • Just pass strs and it will create directories, whether it nested or not. For instance:
  • Macro similar to the vec! macro, but produces std::path::Pathbuf instead of std::vec::Vec
  • Macro similar to the vec! macro, but produces std::path::Pathbuf instead of std::vec::Vec

Structs

  • Structure for convenient work with directories.
  • The main Rob structure.
  • Structure for executing commands (actually just keeping them, but it’s just for now)

Enums

Constants

Type Aliases