Macro robuild::log

source ·
macro_rules! log {
    ($log_level: tt, $($args: tt)*) => { ... };
}
You can log things just like we do in Rob functions, pass the LogLevel enum variant and then format your output like you’r using the println! macro. For instance:

let what = "logging";
log!(INFO, "This is how you can do {what}");

This will print:

[INFO] This is how you can do logging